==> banshee-1-0.98.1.tar.gz: banshee-1-0.98.1/src/Core/Banshee.Services/Banshee.MediaEngine/IPlayerEngineService.cs <==
// 
// IPlayerEngineService.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.MediaEngine
{
    [Interface("org.bansheeproject.Banshee.PlayerEngine")]
    public interface IPlayerEngineService : IDBusExportable
    {
        event DBusPlayerEngineEventHandler EventChanged;
        event DBusPlayerEngineStateHandler StateChanged;
    
        void Open (string uri);
        
        void Close ();
        void Pause ();
        void Play ();
        void TogglePlaying ();
        
        IDictionary<string, object> CurrentTrack { get; }
        string CurrentUri { get; }
        
        string CurrentState { get; }
        string LastState { get; }
    
        ushort Volume { get; set; }
        uint Position { get; set; }
        bool CanSeek { get; }
        bool CanPause { get; }
        uint Length { get; }
    }
}

==> banshee-1-1.5.2.tar.gz: banshee-1-1.5.2/src/Core/Banshee.Services/Banshee.MediaEngine/IPlayerEngineService.cs <==
//
// IPlayerEngineService.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.MediaEngine
{
    [Interface("org.bansheeproject.Banshee.PlayerEngine")]
    public interface IPlayerEngineService : IDBusExportable
    {
        event DBusPlayerEventHandler EventChanged;
        event DBusPlayerStateHandler StateChanged;

        void Open (string uri);

        void Close ();
        void Pause ();
        void Play ();
        void TogglePlaying ();

        IDictionary<string, object> CurrentTrack { get; }
        string CurrentUri { get; }

        string CurrentState { get; }
        string LastState { get; }

        ushort Volume { get; set; }
        uint Position { get; set; }
        bool CanSeek { get; }
        bool CanPause { get; }
        uint Length { get; }
    }
}
